#!/bin/sh

RUN=$(pwd)
. /etc/blackPanther-default-apps.conf

export LD_LIBRARY_PATH=$RUN/lib:$LD_LIBRARY_PATH


if [ "$1" = "-h" ];then
echo 
echo -e "${RED}Wireless Printer Setup Usage on $(lsb_release -sir)"
echo -e "${GRN}Example: $YEL$RUN/bin/wirelesssetup /dev/usb/lp0"
echo 
echo -e "${MAG}The /dev/usb/lp0 <-where connected your printer, please check, possible other port, ex:lp1"
echo -e "$DEF"
exit
fi

$RUN/bin/wirelesssetup $@
